==> cmsmadesimple-1.8.2p0.tgz: cms/modules/TinyMCE/lang/ext/es_ES.php <==
<?php
$lang['friendlyname'] = 'Editor WYSIWYG TinyMCE ';
$lang['uninstalled'] = 'Modulo Desinstalado.';
$lang['installed'] = 'Versi&oacute;n %s instalada.';
$lang['stripbackgroundtags'] = 'Quitar etiquetas del fondo del CSS';
$lang['stiptags_help'] = 'Esta opci&oacute;n trata de remover imagenes de fondo de la plantilla de estilos.';
$lang['source_formatting_text'] = 'Aplicar formato de la fuente para salida HTML';
$lang['dropdownblockformats_text'] = 'Bloquear formatos en el men&uacute; desplegable';
$lang['allowtables'] = 'Permitir tablas';
$lang['newlinestyle_text'] = 'Estilo de nueva l&iacute;nea';
$lang['pstyle'] = 'estilo de &amp;lt;p&amp;gt;';
$lang['brstyle'] = 'estilo de &amp;lt;br/&amp;gt;';
$lang['usecompressiontext'] = 'Usar compresi&oacute;n GZ';
$lang['usecompressionhelp'] = 'Esto puede acelerar la carga de TinyMCE, pero puede que lo obstruya en ciertos sistemas. Usar con cautela';
$lang['forcedrootblocktext'] = 'Forzar <p> como bloque raiz';
$lang['forcedrootblockhelp'] = 'Hace que el contenido regresado sea por lo menos encerrado en una etiqueta <p>';
$lang['filepickerstyle'] = 'Estilo de seleccionador de archivo';
$lang['filepickersize'] = 'Tama&ntilde;o del Seleccionador de Archivos (Filepicker)';
$lang['allowuploadtext'] = 'Permitir subir y crear directorios en el Seleccionador de Archivos (FilePicker)';
$lang['allowscalingtext'] = 'Permitir cambio de tama&ntilde;o instantaneamente al subir imagenes';
$lang['scalingdimensionstext'] = 'Dimensiones por defecto';
$lang['resizeto'] = 'Cambia tama&ntilde;o a:';
$lang['makethumbnail'] = 'Crear miniatura cuando se suban imagenes';
$lang['useadvancedprofile'] = 'Usar perfil avanzado de TinyMCE';
$lang['saveprofile'] = 'Guardar perfil';
$lang['profilesaved'] = 'El perfil fue guardado';
$lang['profiles_tab'] = 'Perfiles';
$lang['advanced_backend_toolbars'] = 'Ajustes avanzados de perfil (area administrativa - backend)';
$lang['savestyles'] = 'Guarar estilos';
$lang['allowadvancedprofile'] = 'Permitir uso de perfiles avanzados en TinyMCE';
$lang['showfilemanagement'] = 'Mostrar opciones de administraci&oacute;n de archivos';
$lang['showfilemanagementhelp'] = 'Mostrar opciones de administraci&oacute;n de archivos como subir, crear directorio, eliminar archivos en FilePicker, si el usuaro tiene permiso de ejecutar estas acciones';
$lang['restrictdirs'] = 'Restringir permisos de acceso a directorios';
$lang['restrictdirshelp'] = 'Esto restringir&aacute; la administraci&oacute;n de archivos del usuario a un sub-directorio de &#039;uploads&#039; que tendr&aacute; el mismo nombre que el nombre de usuario.  Si el sub-directorio no existe, posiblemente ser&aacute; creado. Nota: Esto es un trabajo en proceso y solo funciona con nombres estandar de directorios, uploads/images. Esto puede que cambie en un futuro.';
$lang['deleteconfirmation'] = '&iquest;Est&aacute; seguro que quiere borrar el archivo?';
$lang['deletefilesuccess'] = 'fue borrado';
$lang['deletefilefailed'] = 'no se pudo borrar';
$lang['deletesubdirfailed'] = 'no se pudo borrar';
$lang['deletesubdirsuccess'] = 'se borr&oacute; exitosamente';
$lang['deletedirconfirmation'] = '&iquest;Esta seguro de borrar el directorio vac&iacute;o?';
$lang['deletedir'] = 'Borrar directorio vacio';
$lang['cannotreadconfig'] = 'No se pudo leeer el archivo tinyconfig.php directamente, por lo que TinyMCE no funcionara. Deber&aacute; revisar los permisos de dicho archivo y de los directorios origen, los cuales deben tener permisos de lectura para todos y de escritura para el propietario.';
$lang['filenameonly'] = 'Mostrar nombres de archivo';
$lang['thumbnailsonly'] = 'Mostrar vistas miniatura';
$lang['showthumbnailfilestext'] = 'Mostrar vistas miniatura en listas';
$lang['filenameandthumbnails'] = 'Mostrar nombres de archivo y vistas miniatura';
$lang['skinstext'] = 'Tema (Skin)';
$lang['skinvariationtext'] = 'Variaci&oacute;n de Tema';
$lang['advancedwarning'] = '<strong>Atenci&oacute;n! <br/>El cambio de estos ajustes puede hacer que TinyMCE deje de funcionar o genere codigo erroneo. Cambie esto solo si est&aacute; seguro de lo que est&aacute; haciendo! por favor consulte el sitio de TinyMCE antes de jugar con estos cambios.</strong>';
$lang['entityencoding_text'] = 'Codificado de entidades';
$lang['rawencoding'] = 'Codificado en bruto (m&aacute;s r&aacute;pido, sirve en la mayor&iacute;a de los casos)';
$lang['namedencoding'] = 'Codificado por nombre (del tipo &nbsp;)';
$lang['numericencoding'] = 'Codificado num&eacute;rico (del tipo &amp;#160;)';
$lang['show_path_text'] = 'Mostrar el paso del elemento en el fondo del editor.';
$lang['toolbar_tab'] = 'Barra de Herramientas';
$lang['toolbar_help'] = 'Estas opciones deben contener una lista separada por comas de los botones/nombres de control para insertarlos en la barra de herramientas.';
$lang['toolbar_text'] = 'Barra de Tareas';
$lang['toolbarhelptext'] = 'Haga click aqui para ver intrucciones sobre la barra de herramientas en el wiki de TinyMCE.';
$lang['editor_width_text'] = 'Ancho del campo de edici&oacute;n';
$lang['editor_height_text'] = 'Altura del campo de edici&oacute;n';
$lang['auto'] = 'Automatico';
$lang['or'] = '&oacute;';
$lang['datetimeformat_text'] = 'Formato Fecha/Hora';
$lang['timetext'] = 'Hora';
$lang['datetext'] = 'Fecha';
$lang['datetimeformat_help'] = 'Haga clic aqui para ayuda sobre como formatear la fecha/hora';
$lang['extraconfigtext'] = 'Configuraci&oacute;n extra';
$lang['extraconfighelp2'] = 'Una declaraci&oacute;n por linea, comas ser&aacute;n agregadas antes y despues. Por favor revise el wiki de TinyMCE para mas instrucciones.';
$lang['customdropdowntext'] = 'Men&uacute; desplegable personalizado';
$lang['customdropdownhelp'] = 'Inserta fragmentos personalizados de c&oacute;digo/texto a trav&eacute;s de selecc&iacute;on de un men&uacute; desplegable. Por ejemplo acceso f&aacute;cil a etiquetas, etc. El men&uacute; es insertado en la barra de herramientas usando &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Inicio activado';
$lang['startenabledhelp'] = 'Al desabilitar esto, se iniciar&aacute;n los editores TinyMCE de forma oculta. Se debe utilizar junto con la caja de Mostrar/Ocultar WYSIWYG';
$lang['loadcmslinkertext'] = 'Cargar el CMS-linker';
$lang['loadcmslinkerhelp'] = 'Esto genera el codigo de javascript necesario para permitir que &#039;cmslinker&#039; sea agregado a la barra de herramientas.';
$lang['cmslinkerstyletext'] = 'Estilo de enlaces CMS-linker';
$lang['cmsselflinkstyle'] = 'Estilo {cms_selflink}(con soporte para URLs amigables)';
$lang['ahrefstyle'] = 'estilo <a href>(sin soporte de a URLs amigables)';
$lang['relativeurlstext'] = 'Generar URLs relativos';
$lang['forcecleanpastetext'] = 'Forzar limpieza al pegar';
$lang['forcecleanpastehelp'] = 'Esto deberia de estar habilitado para remover codigos extra&ntilde;os de formato cuando se pega contenido de Word, etc.';
$lang['bodycss_text'] = 'CSS para etiqueta Body';
$lang['bodycss_help'] = 'deje BLANK o establezca DEFAULT para usar PAGE CSS. Nota: Para que el fondo del editor sea de color blanco ponga lo siguiente en el blank: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Incluir solo CSS de pantalla';
$lang['includeonlyscreencss_help'] = 'Seleccionar esto permite que solo plantillas de estilos que tienen el medio:pantalla seleccionado, sean incluidos en los estilos que TinyMCE maneja.';
$lang['usestaticconfigtext'] = 'Usar un archivo de configuraci&oacute;n est&aacute;tico';
$lang['usestaticconfighelp'] = 'Esto puede ayudar a que TinyMCE funcione en sistemas en los que las facilidades de hospedaje a&ntilde;aden cosas como estadisticas etc, lo cual rompe el archivo de configuracion javascript creado dinamicamente.';
$lang['usestaticconfigwarning'] = 'Advertencia! Tiene la opci&oacute;n de Archivo de Configuraci&oacute;n Estatico habilitada pero el directorio /tmp/ no tiene permiso de escritura. Esto previene al modulo de guardar el archivo estatico y es muy probable que TinyMCE no funcione.';
$lang['showtogglebutton_text'] = 'Mostrar caja de tildar para abrir/cerrar WYSIWYG';
$lang['togglewysiwyg'] = 'Mostrar/Ocultar WYSIWYG';
$lang['styles_tab'] = 'Estilos CSS';
$lang['styles_help'] = 'Si usted deja el campo vac&iacute;o, TinyMCE va a parsear su archivo CSS y listar los estilos contenidos en &eacute;l, al usuario. Si usted lo que desea es s&oacute;lo presentar al usuario algunos estilos, especifique a ellos de la forma &quot;Style 1=style1; Style 2=style2&quot; en el primer campo de abajo. En los campos restantes, usted puede especificar los estilos CSS para Tablas, Filas, y Celdas que son utilizados en los correspondientes di&aacute;logos. Para un campo vac&iacute;o, se usar&aacute; el estilo del estilo general.';
$lang['css_styles_text'] = 'General';
$lang['accessdenied'] = 'Acceso Negado. Por favor controle sus permisos.';
$lang['error'] = '&iexcl;Error!';
$lang['submit'] = 'Enviar';
$lang['update'] = 'Actualizar';
$lang['savesettings'] = 'Guardar ajustes';
$lang['settings'] = 'Configuraciones';
$lang['settingssaved'] = 'Las configuraciones fueron guardadas';
$lang['saveadvanced'] = 'Guardad ajustes avanzados';
$lang['advancedsaved'] = 'Ajustes avanzados han sido guardados';
$lang['toolbarsaved'] = 'La Barra de Tareas fue guardada';
$lang['stylessaved'] = 'Los Estilos fueron guardados';
$lang['testareatext'] = '<p>&Aacute;rea de pruebas, no se har&aacute; da&ntilde;o a ning&uacute;n contenido jugando con esto...</p>';
$lang['reset'] = 'Restaurar valores por defecto';
$lang['resetall'] = 'Restaurar todos los ajustes a valores por defecto';
$lang['confirmreset'] = '&iquest;Est&aacute; seguro de querer restaurar estos ajustes a sus valores por defecto?';
$lang['confirmresetall'] = '&iquest;Est&aacute; seguro de querer restaurar TODOS los ajustes a sus valores por defecto?';
$lang['settingsreset'] = 'Los ajustes han sido restaurados a valores por defecto';
$lang['allsettingsreset'] = 'Todos los ajustes han sido restaurados a valores por defecto';
$lang['upgraded'] = 'ha sido actualizado a version';
$lang['customdropdown'] = 'Men&uacute; desplegable personalizado';
$lang['cmsmslinker'] = 'Insertar enlace a p&aacute;gina de cmsms';
$lang['backend_toolbars'] = 'Configuraci&oacute;n de la barra de herramientas del area administrativa';
$lang['frontend_toolbars'] = 'Configuraci&oacute;n de la barra de herramientas de visitantes';
$lang['plugins_tab'] = 'Plugins ';
$lang['plugins_help'] = 'Seleccionar que plugins desea activar. La documentaci&oacute;n la encuentra <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">aqui</a>';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Guardar plugins';
$lang['pluginssaved'] = 'Plugins guardados';
$lang['youareintext'] = 'Usted est&aacute; en';
$lang['loadstylesheettext'] = 'Cargar hoja de estilos para el contenido (se recomienda)';
$lang['extrastylestext'] = 'Adiciones a la plantilla de estilos';
$lang['extrastyleshelp'] = 'Estilos CSS ingresados aqui seran a&ntilde;adidos a la plantilla de estilos leidos por TinyMCE despues de que recibe los estilos de CMSms.';
$lang['uploadnewfile'] = 'Nuevo Archivo';
$lang['uploadfile'] = 'Subir';
$lang['createnewdir'] = 'Nuevo Directorio';
$lang['createdir'] = 'Crear';
$lang['nodirname'] = 'No se ingres&oacute; un nombre de directorio';
$lang['direxists'] = 'Ya existe un directorio con ese nombre';
$lang['newdircreated'] = 'Nuevo directorio fue creado';
$lang['newdirfailed'] = 'Ocurri&oacute; un error al tratar de crear el directorio';
$lang['nofile'] = 'No se subi&oacute; ning&uacute;n archivo';
$lang['filetoobig'] = 'El archivo subido es demasiado grande';
$lang['containsillegalchars'] = 'El nombre de archivo contiene caracteres inv&aacute;lidos (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Error al mover el archivo subido';
$lang['fileuploaded'] = 'El archivo fue subido con exito';
$lang['filepickertitle'] = 'CMSMadeSimple Seleccion de Archivo';
$lang['success'] = '&Eacute;xito';
$lang['fileoperations'] = 'Operaciones de archivo';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Tama&ntilde;o';
$lang['dimensions'] = 'Alto x Ancho';
$lang['advanced_tab'] = 'Avanzado';
$lang['help'] = '	<h3>&iquest;Que hace esto?</h3>
	<p>Permite usar a TinyMCE como editor WYSIWYG de sus p&aacute;ginas.</p>
	<h3>&iquest;Como lo uso?</h3>
	<p>Instalar el m&oacute;dulo, luego ir a preferencias de usuario y elegir a TinyMCE como el editor wysiwyg de su elecci&oacute;n.</p>';
$lang['qca'] = 'P0-2096054370-1259803615939';
$lang['utma'] = '156861353.238606854.1259804368.1267940197.1267946953.72';
$lang['utmz'] = '156861353.1267925726.70.33.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/TinyMCE/lang/ext/es_ES.php <==
<?php
$lang['friendlyname'] = 'Editor WYSIWYG TinyMCE ';
$lang['admindescription'] = 'Este modulo permite principalmente contenido, pero posiblemente tambien otro tipo de informaci&oacute;n, que es editado usando el editor WYSIWYG impulsado por el proyecto TinyMCE.';
$lang['uninstalled'] = 'Modulo Desinstalado.';
$lang['installed'] = 'Versi&oacute;n %s instalada.';
$lang['stripbackgroundtags'] = 'Quitar etiquetas del fondo del CSS';
$lang['stiptags_help'] = 'Esta opci&oacute;n trata de remover imagenes de fondo de la plantilla de estilos.';
$lang['source_formatting_text'] = 'Aplicar formato de la fuente para salida HTML';
$lang['dropdownblockformats_text'] = 'Bloquear formatos en el men&uacute; desplegable';
$lang['allowtables'] = 'Permitir tablas';
$lang['newlinestyle_text'] = 'Estilo de nueva l&iacute;nea';
$lang['pstyle'] = 'estilo de &amp;lt;p&amp;gt;';
$lang['brstyle'] = 'estilo de &amp;lt;br/&amp;gt;';
$lang['usecompressiontext'] = 'Usar compresi&oacute;n GZ';
$lang['usecompressionhelp'] = 'Esto puede acelerar la carga de TinyMCE, pero puede que lo obstruya en ciertos sistemas. Usar con cautela';
$lang['forcedrootblocktext'] = 'Forzar <p> como bloque raiz';
$lang['forcedrootblockhelp'] = 'Hace que el contenido regresado sea por lo menos encerrado en una etiqueta <p>';
$lang['filepickerstyle'] = 'Estilo de seleccionador de archivo';
$lang['filepickersize'] = 'Tama&ntilde;o del Seleccionador de Archivos (Filepicker)';
$lang['allowuploadtext'] = 'Permitir subir y crear directorios en el Seleccionador de Archivos (FilePicker)';
$lang['allowscalingtext'] = 'Permitir cambio de tama&ntilde;o instantaneamente al subir imagenes';
$lang['scalingdimensionstext'] = 'Dimensiones por defecto';
$lang['resizeto'] = 'Cambia tama&ntilde;o a:';
$lang['makethumbnail'] = 'Crear miniatura cuando se suban imagenes';
$lang['useadvancedprofile'] = 'Usar perfil avanzado de TinyMCE';
$lang['saveprofile'] = 'Guardar perfil';
$lang['profilesaved'] = 'El perfil fue guardado';
$lang['profiles_tab'] = 'Perfiles';
$lang['advanced_backend_toolbars'] = 'Ajustes avanzados de perfil (area administrativa - backend)';
$lang['savestyles'] = 'Guarar estilos';
$lang['allowadvancedprofile'] = 'Permitir uso de perfiles avanzados en TinyMCE';
$lang['showfilemanagement'] = 'Mostrar opciones de administraci&oacute;n de archivos';
$lang['showfilemanagementhelp'] = 'Mostrar opciones de administraci&oacute;n de archivos como subir, crear directorio, eliminar archivos en FilePicker, si el usuaro tiene permiso de ejecutar estas acciones';
$lang['restrictdirs'] = 'Restringir permisos de acceso a directorios';
$lang['restrictdirshelp'] = 'Esto restringir&aacute; la administraci&oacute;n de archivos del usuario a un sub-directorio de &#039;uploads&#039; que tendr&aacute; el mismo nombre que el nombre de usuario.  Si el sub-directorio no existe, posiblemente ser&aacute; creado. Nota: Esto es un trabajo en proceso y solo funciona con nombres estandar de directorios, uploads/images. Esto puede que cambie en un futuro.';
$lang['deleteconfirmation'] = '&iquest;Est&aacute; seguro que quiere borrar el archivo?';
$lang['deletefilesuccess'] = 'fue borrado';
$lang['deletefilefailed'] = 'no se pudo borrar';
$lang['deletesubdirfailed'] = 'no se pudo borrar';
$lang['deletesubdirsuccess'] = 'se borr&oacute; exitosamente';
$lang['deletedirconfirmation'] = '&iquest;Esta seguro de borrar el directorio vac&iacute;o?';
$lang['deletedir'] = 'Borrar directorio vacio';
$lang['deletefile'] = 'Borrar archivo';
$lang['cannotreadconfig'] = 'No se pudo leeer el archivo tinyconfig.php directamente, por lo que TinyMCE no funcionara. Deber&aacute; revisar los permisos de dicho archivo y de los directorios origen, los cuales deben tener permisos de lectura para todos y de escritura para el propietario.';
$lang['filenameonly'] = 'Mostrar nombres de archivo';
$lang['thumbnailsonly'] = 'Mostrar vistas miniatura';
$lang['showthumbnailfilestext'] = 'Mostrar vistas miniatura en listas';
$lang['filenameandthumbnails'] = 'Mostrar nombres de archivo y vistas miniatura';
$lang['skinstext'] = 'Tema (Skin)';
$lang['skinvariationtext'] = 'Variaci&oacute;n de Tema';
$lang['advancedwarning'] = '<strong>Atenci&oacute;n! <br/>El cambio de estos ajustes puede hacer que TinyMCE deje de funcionar o genere codigo erroneo. Cambie esto solo si est&aacute; seguro de lo que est&aacute; haciendo! por favor consulte el sitio de TinyMCE antes de jugar con estos cambios.</strong>';
$lang['entityencoding_text'] = 'Codificado de entidades';
$lang['rawencoding'] = 'Codificado en bruto (m&aacute;s r&aacute;pido, sirve en la mayor&iacute;a de los casos)';
$lang['namedencoding'] = 'Codificado por nombre (del tipo &nbsp;)';
$lang['numericencoding'] = 'Codificado num&eacute;rico (del tipo &amp;#160;)';
$lang['show_path_text'] = 'Mostrar el paso del elemento en el fondo del editor.';
$lang['toolbar_tab'] = 'Barra de Herramientas';
$lang['toolbar_help'] = 'Estas opciones deben contener una lista separada por comas de los botones/nombres de control para insertarlos en la barra de herramientas.';
$lang['toolbar_text'] = 'Barra de Tareas';
$lang['toolbarhelptext'] = 'Haga click aqui para ver intrucciones sobre la barra de herramientas en el wiki de TinyMCE.';
$lang['editor_width_text'] = 'Ancho del campo de edici&oacute;n';
$lang['editor_height_text'] = 'Altura del campo de edici&oacute;n';
$lang['auto'] = 'Automatico';
$lang['or'] = '&oacute;';
$lang['testarea_tab'] = 'Area de prueba';
$lang['showtestingoutput'] = 'Mostrar salida de la prueba';
$lang['testareaeditor'] = 'Editor de area de prueba';
$lang['testareaoutput'] = 'Salida del area de prueba';
$lang['testareaoutputsource'] = 'Origen del area de prueba';
$lang['allowresizing'] = 'Permitir cambio de tama&ntilde;o del campo del editor';
$lang['resizenone'] = 'No permitir cambio de tama&ntilde;o';
$lang['resizeboth'] = 'Permitir cambio de tama&ntilde;o en ambas direcciones';
$lang['resizeheight'] = 'Permitir solo cambio del tama&ntilde;o de la altura';
$lang['datetimeformat_text'] = 'Formato Fecha/Hora';
$lang['timetext'] = 'Hora';
$lang['datetext'] = 'Fecha';
$lang['datetimeformat_help'] = 'Haga clic aqui para ayuda sobre como formatear la fecha/hora';
$lang['extraconfigtext'] = 'Configuraci&oacute;n extra';
$lang['extraconfighelp2'] = 'Una declaraci&oacute;n por linea, comas ser&aacute;n agregadas antes y despues. Por favor revise el wiki de TinyMCE para mas instrucciones.';
$lang['customdropdowntext'] = 'Men&uacute; desplegable personalizado';
$lang['customdropdownhelp'] = 'Inserta fragmentos personalizados de c&oacute;digo/texto a trav&eacute;s de selecc&iacute;on de un men&uacute; desplegable. Por ejemplo acceso f&aacute;cil a etiquetas, etc. El men&uacute; es insertado en la barra de herramientas usando &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'Inicio activado';
$lang['startenabledhelp'] = 'Al desabilitar esto, se iniciar&aacute;n los editores TinyMCE de forma oculta. Se debe utilizar junto con la caja de Mostrar/Ocultar WYSIWYG';
$lang['loadcmslinkertext'] = 'Cargar el CMS-linker';
$lang['loadcmslinkerhelp'] = 'Esto genera el codigo de javascript necesario para permitir que &#039;cmslinker&#039; sea agregado a la barra de herramientas.';
$lang['cmslinkerstyletext'] = 'Estilo de enlaces CMS-linker';
$lang['cmsselflinkstyle'] = 'Estilo {cms_selflink}(con soporte para URLs amigables)';
$lang['ahrefstyle'] = 'estilo <a href>(sin soporte de a URLs amigables)';
$lang['cmslinkeraddstext'] = 'Adiciones de CMS-linker';
$lang['cmslinkeraddshelp'] = 'Esto permite agregar a la etiqueta html <a href> &oacute; {cms_selflink}, cuando es generada  con CMS-linker';
$lang['avoidlinkconversiontext'] = 'Evitar conversi&oacute;n de enlaces';
$lang['avoidlinkconversionhelp'] = 'Enciende o apaga la l&oacute;gica de conversi&oacute;n de enlaces de TinyMCE. Permite que el uso de urls con {smarty} sean posibles.';
$lang['relativeurlstext'] = 'Generar URLs relativos';
$lang['forcecleanpastetext'] = 'Forzar limpieza al pegar';
$lang['forcecleanpastehelp'] = 'Esto deberia de estar habilitado para remover codigos extra&ntilde;os de formato cuando se pega contenido de Word, etc.';
$lang['bodycss_text'] = 'CSS para etiqueta Body';
$lang['bodycss_help'] = 'deje BLANK o establezca DEFAULT para usar PAGE CSS. Nota: Para que el fondo del editor sea de color blanco ponga lo siguiente en el blank: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Incluir solo CSS de pantalla';
$lang['includeonlyscreencss_help'] = 'Seleccionar esto permite que solo plantillas de estilos que tienen el medio:pantalla seleccionado, sean incluidos en los estilos que TinyMCE maneja.';
$lang['usestaticconfigtext'] = 'Usar un archivo de configuraci&oacute;n est&aacute;tico';
$lang['usestaticconfighelp'] = 'Esto puede ayudar a que TinyMCE funcione en sistemas en los que las facilidades de hospedaje a&ntilde;aden cosas como estadisticas etc, lo cual rompe el archivo de configuracion javascript creado dinamicamente.';
$lang['usestaticconfigwarning'] = 'Advertencia! Tiene la opci&oacute;n de Archivo de Configuraci&oacute;n Estatico habilitada pero el directorio /tmp/ no tiene permiso de escritura. Esto previene al modulo de guardar el archivo estatico y es muy probable que TinyMCE no funcione.';
$lang['ignoremodifyfilestext'] = 'Ignorar el permiso de &#039;Modificar Archivos&#039; para FilePicker';
$lang['ignoremodifyfileshelp'] = '&iexcl;Advertencia! Esto permite algunas operaciones de alteraci&oacute;n de archivos aunque el permiso de &#039;Modificar Archivos&#039; no haya sido establecido para el grupo de usuario actual. Esto puede ser utilizado conjuntamente con la opci&oacute;n de restricci&oacute;n de acceso a carpetas  para los usuarios.';
$lang['showtogglebutton_text'] = 'Mostrar caja de tildar para abrir/cerrar WYSIWYG';
$lang['togglewysiwyg'] = 'Mostrar/Ocultar WYSIWYG';
$lang['styles_tab'] = 'Estilos CSS';
$lang['styles_help'] = 'Si usted deja el campo vac&iacute;o, TinyMCE va a parsear su archivo CSS y listar los estilos contenidos en &eacute;l, al usuario. Si usted lo que desea es s&oacute;lo presentar al usuario algunos estilos, especifique a ellos de la forma &quot;Style 1=style1; Style 2=style2&quot; en el primer campo de abajo. En los campos restantes, usted puede especificar los estilos CSS para Tablas, Filas, y Celdas que son utilizados en los correspondientes di&aacute;logos. Para un campo vac&iacute;o, se usar&aacute; el estilo del estilo general.';
$lang['css_styles_text'] = 'General';
$lang['accessdenied'] = 'Acceso Negado. Por favor controle sus permisos.';
$lang['error'] = '&iexcl;Error!';
$lang['submit'] = 'Enviar';
$lang['update'] = 'Actualizar';
$lang['savesettings'] = 'Guardar ajustes';
$lang['settings'] = 'Configuraciones';
$lang['settingssaved'] = 'Las configuraciones fueron guardadas';
$lang['saveadvanced'] = 'Guardad ajustes avanzados';
$lang['advancedsaved'] = 'Ajustes avanzados han sido guardados';
$lang['toolbarsaved'] = 'La Barra de Tareas fue guardada';
$lang['stylessaved'] = 'Los Estilos fueron guardados';
$lang['testareatext'] = '<p>&Aacute;rea de pruebas, no se har&aacute; da&ntilde;o a ning&uacute;n contenido jugando con esto...</p>';
$lang['reset'] = 'Restaurar valores por defecto';
$lang['resetall'] = 'Restaurar todos los ajustes a valores por defecto';
$lang['confirmreset'] = '&iquest;Est&aacute; seguro de querer restaurar estos ajustes a sus valores por defecto?';
$lang['confirmresetall'] = '&iquest;Est&aacute; seguro de querer restaurar TODOS los ajustes a sus valores por defecto?';
$lang['settingsreset'] = 'Los ajustes han sido restaurados a valores por defecto';
$lang['allsettingsreset'] = 'Todos los ajustes han sido restaurados a valores por defecto';
$lang['upgraded'] = 'ha sido actualizado a version';
$lang['customdropdown'] = 'Men&uacute; desplegable personalizado';
$lang['cmsmslinker'] = 'Insertar enlace a p&aacute;gina de cmsms';
$lang['backend_toolbars'] = 'Configuraci&oacute;n de la barra de herramientas del area administrativa';
$lang['frontend_toolbars'] = 'Configuraci&oacute;n de la barra de herramientas de visitantes';
$lang['plugins_tab'] = 'Plugins ';
$lang['plugins_help'] = 'Seleccionar que plugins desea activar. La documentaci&oacute;n la encuentra <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">aqui</a>';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Guardar plugins';
$lang['pluginssaved'] = 'Plugins guardados';
$lang['plugins_module'] = 'Plugins del M&oacute;dulo';
$lang['plugins_common'] = 'Plugins comunes';
$lang['module'] = 'Modulo';
$lang['description'] = 'Descripci&oacute;n';
$lang['plugin'] = 'Plugin ';
$lang['youareintext'] = 'Usted est&aacute; en';
$lang['loadstylesheettext'] = 'Cargar hoja de estilos para el contenido (se recomienda)';
$lang['extrastylestext'] = 'Adiciones a la plantilla de estilos';
$lang['extrastyleshelp'] = 'Estilos CSS ingresados aqui seran a&ntilde;adidos a la plantilla de estilos leidos por TinyMCE despues de que recibe los estilos de CMSms.';
$lang['uploadnewfile'] = 'Nuevo Archivo';
$lang['uploadfile'] = 'Subir';
$lang['createnewdir'] = 'Nuevo Directorio';
$lang['createdir'] = 'Crear';
$lang['nodirname'] = 'No se ingres&oacute; un nombre de directorio';
$lang['direxists'] = 'Ya existe un directorio con ese nombre';
$lang['newdircreated'] = 'Nuevo directorio fue creado';
$lang['newdirfailed'] = 'Ocurri&oacute; un error al tratar de crear el directorio';
$lang['nofile'] = 'No se subi&oacute; ning&uacute;n archivo';
$lang['filetoobig'] = 'El archivo subido es demasiado grande';
$lang['containsillegalchars'] = 'El nombre de archivo contiene caracteres inv&aacute;lidos (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Error al mover el archivo subido';
$lang['fileuploaded'] = 'El archivo fue subido con exito';
$lang['notanimage'] = 'El archivo enviado no es una imagen';
$lang['filepickertitle'] = 'CMSMadeSimple Seleccion de Archivo';
$lang['success'] = '&Eacute;xito';
$lang['fileoperations'] = 'Operaciones de archivo';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Tama&ntilde;o';
$lang['dimensions'] = 'Alto x Ancho';
$lang['advanced_tab'] = 'Avanzado';
$lang['help'] = '	<h3>&iquest;Que hace esto?</h3>
	<p>Permite usar a TinyMCE como editor WYSIWYG de sus p&aacute;ginas.</p>
	<h3>&iquest;Como lo uso?</h3>
	<p>Instalar el m&oacute;dulo, luego ir a preferencias de usuario y elegir a TinyMCE como el editor wysiwyg de su elecci&oacute;n.</p>';
$lang['qca'] = 'P0-672577724-1291068511180';
$lang['utmz'] = '156861353.1291068584.1.2.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['utma'] = '156861353.761306410.1291068511.1297984934.1298856162.17';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
